@@ -1,14 +1,14 @@
 /*
  * This file is part of the xTuple ERP: PostBooks Edition, a free and
  * open source Enterprise Resource Planning software suite,
- * Copyright (c) 1999-2012 by OpenMFG LLC, d/b/a xTuple.
+ * Copyright (c) 1999-2015 by OpenMFG LLC, d/b/a xTuple.
  * It is licensed to you under the Common Public Attribution License
  * version 1.0, the full text of which (including xTuple-specific Exhibits)
  * is available at www.xtuple.com/CPAL.  By using this software, you agree
  * to be bound by its terms.
  */
 
-#include <qapplication.h>
+#include <QApplication>
 
 #include "packagewindow.h"
 
@@ -19,7 +19,6 @@ int main(int argc, char *argv[])
   PackageWindow * mainwin = new PackageWindow();
   mainwin->show();
 
-  app.setMainWidget(mainwin);
   return app.exec();
 }
 
