@@ -1,7 +1,7 @@
 /*
  * This file is part of the xTuple ERP: PostBooks Edition, a free and
  * open source Enterprise Resource Planning software suite,
- * Copyright (c) 1999-2012 by OpenMFG LLC, d/b/a xTuple.
+ * Copyright (c) 1999-2015 by OpenMFG LLC, d/b/a xTuple.
  * It is licensed to you under the Common Public Attribution License
  * version 1.0, the full text of which (including xTuple-specific Exhibits)
  * is available at www.xtuple.com/CPAL.  By using this software, you agree
@@ -31,9 +31,7 @@ class LoadCmd : public Loadable
                                         && !_title.isEmpty()
                                         && !_executable.isEmpty(); }
 
-    virtual int writeToDB(const QByteArray &, const QString pkgname,
-                          QString &errMsg) { return writeToDB(pkgname, errMsg); }
-    virtual int writeToDB(const QString pkgname, QString &errMsg);
+    virtual int writeToDB(const QByteArray &, const QString pkgname, QString &errMsg);
 
   protected:
     QStringList _args;
